[llvm-commits] CVS: llvm/include/llvm/CodeGen/ScheduleDAG.h SelectionDAGISel.h

Chris Lattner lattner at cs.uiuc.edu
Tue Mar 7 20:25:07 PST 2006



Changes in directory llvm/include/llvm/CodeGen:

ScheduleDAG.h updated: 1.14 -> 1.15
SelectionDAGISel.h updated: 1.10 -> 1.11
---
Log message:

Change the interface for getting a target HazardRecognizer to be more clean.


---
Diffs of the changes:  (+6 -9)

 ScheduleDAG.h      |    9 +++------
 SelectionDAGISel.h |    6 +++---
 2 files changed, 6 insertions(+), 9 deletions(-)


Index: llvm/include/llvm/CodeGen/ScheduleDAG.h
diff -u llvm/include/llvm/CodeGen/ScheduleDAG.h:1.14 llvm/include/llvm/CodeGen/ScheduleDAG.h:1.15
--- llvm/include/llvm/CodeGen/ScheduleDAG.h:1.14	Sun Mar  5 18:20:29 2006
+++ llvm/include/llvm/CodeGen/ScheduleDAG.h	Tue Mar  7 22:24:56 2006
@@ -57,10 +57,6 @@
       NoopHazard,    // This instruction can't be emitted, and needs noops.
     };
     
-    /// StartBasicBlock - This is called when a new basic block is started.
-    ///
-    virtual void StartBasicBlock() {}
-    
     /// getHazardType - Return the hazard type of emitting this node.  There are
     /// three possible results.  Either:
     ///  * NoHazard: it is legal to issue this instruction on this cycle.
@@ -410,10 +406,11 @@
                                           MachineBasicBlock *BB);
   
   /// createTDListDAGScheduler - This creates a top-down list scheduler with
-  /// the specified hazard recognizer.
+  /// the specified hazard recognizer.  This takes ownership of the hazard
+  /// recognizer and deletes it when done.
   ScheduleDAG* createTDListDAGScheduler(SelectionDAG &DAG,
                                         MachineBasicBlock *BB,
-                                        HazardRecognizer &HR);
+                                        HazardRecognizer *HR);
 }
 
 #endif


Index: llvm/include/llvm/CodeGen/SelectionDAGISel.h
diff -u llvm/include/llvm/CodeGen/SelectionDAGISel.h:1.10 llvm/include/llvm/CodeGen/SelectionDAGISel.h:1.11
--- llvm/include/llvm/CodeGen/SelectionDAGISel.h:1.10	Sun Mar  5 18:20:29 2006
+++ llvm/include/llvm/CodeGen/SelectionDAGISel.h	Tue Mar  7 22:24:56 2006
@@ -62,9 +62,9 @@
     return true;
   }
   
-  /// GetTargetHazardRecognizer - Return the hazard recognizer to use for this
-  /// target when scheduling the DAG.
-  virtual HazardRecognizer &GetTargetHazardRecognizer();
+  /// CreateTargetHazardRecognizer - Return a newly allocated hazard recognizer
+  /// to use for this target when scheduling the DAG.
+  virtual HazardRecognizer *CreateTargetHazardRecognizer();
   
 protected:
   /// Pick a safe ordering and emit instructions for each target node in the






More information about the llvm-commits mailing list